@@ -168,6 +168,17 @@ public class ConfigurationProperties {
      */
     public static final String OX_ACCESS_RELOGIN_ERROR_CODES_DEFAULT = "SES-0202,SES-0203,SES-0206";
 
+    /**
+     * This property defines a list of OX error codes that signify non-existing PIM items
+     */
+    public static final String OX_ACCESS_MISSING_OBJECT_ERROR_CODES_PROPERTY = "com.openexchange.usm.ox.missing_object_error_codes";
+
+    /**
+     * Default value for com.openexchange.usm.ox.missing_object_error_codes
+     */
+    /* As a suggestion from Bug 36808 this has been made configurable */
+    public static final String OX_ACCESS_MISSING_OBJECT_ERROR_CODES_DEFAULT = "MSG-0032,OX-0001,CON-0125,TSK-0019";
+
     /**
      * This property defines how long a synchronization request will wait for exclusive access to the object (specific folder or folder hierarchy) that
      * it wants to synchronize.
