@@ -59,11 +59,22 @@ import org.json.JSONException;
  * @param <T> Java type of object that is stored by the DataType
  */
 public abstract class AbstractDataType<T extends Serializable> implements DataType<T> {
+    
+    private final String name;
+    
+    /**
+     * Initializes a new {@link AbstractDataType}.
+     * @param n
+     */
+    public AbstractDataType(String n) {
+        name = n;
+    }
 
     protected void generateTypeError(Object o) {
         throw new IllegalArgumentException(o.getClass().getName() + " is no " + getName());
     }
 
+    @Override
     public T createNewObject() {
         return null;
     }
@@ -71,22 +82,27 @@ public abstract class AbstractDataType<T extends Serializable> implements DataTy
     /**
      * Must be overwritten for all DataTypes that do not use immutable Objects
      */
+    @Override
     public T createCopy(Object source) {
         return checkValue(source);
     }
 
+    @Override
     public Serializable serialize(Object value) {
         return createCopy(value);
     }
 
+    @Override
     public T deserialize(Serializable value) {
         return createCopy(value);
     }
 
+    @Override
     public boolean isEqual(Object object, Object object2) {
         return (object == null) ? object2 == null : object.equals(object2);
     }
 
+    @Override
     public boolean isDefaultValue(Object object) {
         return object == null;
     }
@@ -100,4 +116,13 @@ public abstract class AbstractDataType<T extends Serializable> implements DataTy
             throw new JSONException("Element is not a Number");
         }
     }
+    
+    /*
+     * (non-Javadoc)
+     * @see com.openexchange.usm.api.datatypes.DataType#getName()
+     */
+    @Override
+    public String getName() {
+        return name;
+    }
 }
