@@ -60,31 +60,35 @@ import com.openexchange.usm.api.session.Session;
  *
  */
 public class BooleanDataType extends AbstractDataType<Boolean> {
-	public static final String NAME = "Boolean";
-
-	public void addToJSONArray(Session session, JSONArray parent, Object object) throws JSONException {
-		parent.put((Boolean) object);
+	
+	public BooleanDataType() {
+	    super("Boolean");
 	}
 
-	public Boolean checkValue(Object o) {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object object) {
+		parent.put(object);
+	}
+
+	@Override
+    public Boolean checkValue(Object o) {
 		if (o != null && !(o instanceof Boolean))
 			generateTypeError(o);
 		return (Boolean) o;
 	}
 
-	public Boolean extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public Boolean extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? null : array.getBoolean(index);
 	}
 
-	public Boolean extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
+	@Override
+    public Boolean extractFromJSONObject(Session session, JSONObject jsonObject, String field) throws JSONException {
 		return jsonObject.isNull(field) ? null : jsonObject.getBoolean(field);
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
-		parent.put(field, (Boolean) object);
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object object) throws JSONException {
+		parent.put(field, object);
 	}
 }
