@@ -95,6 +95,15 @@ public interface SessionInitializer {
      */
     void checkAccess(Session session) throws USMException;
 
+    /**
+     * Called if the default mail folders have changed.
+     * 
+     * @param session
+     * @param ajaxConfiguration
+     * @throws USMException
+     */
+    void updateDefaultFolders(Session session, JSONObject ajaxConfiguration) throws USMException;
+
     /**
      * @return true if this protocol expects modified folders to be reported on each waitForChanges()-call. If this method returns false,
      *         the internal modified flag will be reset after the folder has been reported as modified for a few (internally configured)
