@@ -49,7 +49,9 @@
 package com.openexchange.usm.api.session;
 
 import java.util.Map;
+import com.openexchange.annotation.NonNull;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.ox.event.OXEventListener;
 
 /**
  * Service that provides access to a Session. A Session is uniquely
@@ -58,7 +60,7 @@ import com.openexchange.usm.api.exceptions.USMException;
  * @author afe
  *
  */
-public interface SessionManager {
+public interface SessionManager extends OXEventListener {
 	/**
 	 * Request a specific Session. When the Session is returned, it
 	 * is guaranteed that the Session either is correctly authenticated
@@ -105,8 +107,24 @@ public interface SessionManager {
 	 * @return
 	 * @throws USMException
 	 */
-	Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer,
+	@NonNull Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer,
 			String clientIP, Map<String, String> xHeaders) throws USMException;
 
 	boolean existsSessionInDB(String user, String password, String protocol, String device) throws USMException;
+
+	/**
+	 * This method enables waiting for the specified timeout in the Session.waitForChanges() method. If waiting is not enabled, waitForChanges() will
+	 * always ignore the timeout and return immediately.
+	 * 
+	 * @param protocol
+	 */
+	void enableWaitingForChanges(String protocol);
+
+	/**
+	 * This method disables waiting in the Session.waitForChanges() method. Any threads that are currently waiting will get notified and will stop
+	 * waiting. Any future calls to waitForChanges() will return immediately (until enableWaitingForChanges is called again).
+	 * 
+	 * @param protocol
+	 */
+	void disableWaitForChanges(String protocol);
 }
