@@ -50,7 +50,10 @@
 package com.openexchange.usm.clt;
 
 import java.io.IOException;
+import java.io.PrintWriter;
+import java.io.StringWriter;
 import java.util.ArrayList;
+import java.util.Comparator;
 import java.util.List;
 import java.util.Map;
 import java.util.Map.Entry;
@@ -80,6 +83,8 @@ import com.openexchange.usm.clt.eas12.EASBase64RequestParser;
  */
 public class USMSessionTool {
 
+    private static final int _WIDTH = 76;
+
     private static final String _USM_PROTOCOL_JSON = "JSON";
 
     private static final String _USM_PROTOCOL_EAS = "EAS";
@@ -92,44 +97,160 @@ public class USMSessionTool {
 
     private static final Options toolOptions;
 
+    private static final Options normalOptions;
+
+    private static final Options helpOptions;
+
     static {
         final Options opts = new Options();
-        opts.addOption("h", "help", false, "Prints a help text");
-        opts.addOption("l", "login", true, "The optional JMX login (if JMX has authentication enabled)");
-        opts.addOption("p", "port", true, "The optional JMX port (default:9999)");
-        opts.addOption("s", "password", true, "The optional JMX password (if JMX has authentication enabled)");
+        final Options helpOpts = new Options();
+        final Options normalOpts = new Options();
         OptionGroup easLogging = new OptionGroup();
-        easLogging.addOption(new Option(
+        Option o = new Option(
             "e",
             "enableEASDebugLog",
             true,
-            "Enable EAS debug logging with the given keyword in the log messages"));
-        easLogging.addOption(new Option("d", "disableEASDebugLog", false, "Disable EAS debug logging"));
-        easLogging.addOption(new Option("r", "reportEASDebugLog", false, "Report if (and under which keyword) EAS debug logging is enabled"));
+            "Enable EAS debug logging with the given keyword in the log messages (only for EAS sessions)");
+        o.setArgName("keyword");
+        easLogging.addOption(o);
+        easLogging.addOption(new Option(
+            "r",
+            "reportEASDebugLog",
+            false,
+            "Report if (and under which keyword) debug logging is enabled (only for EAS sessions)"));
+        easLogging.addOption(new Option("d", "disableEASDebugLog", false, "Disable debug logging (only for EAS sessions)"));
         easLogging.setRequired(false);
         opts.addOptionGroup(easLogging);
+        normalOpts.addOptionGroup(easLogging);
         OptionGroup verbosity = new OptionGroup();
-        verbosity.addOption(new Option("v", "verbose", false, "Verbose output: Report all persistent fields for matching USM sessions"));
         verbosity.addOption(new Option(
             "q",
             "quiet",
             false,
             "Quiet mode: Only print errors/warnings. If -r is specified, print only EAS debug logging keyword (or empty line if EAS debug logging is disabled)"));
+        verbosity.addOption(new Option("v", "verbose", false, "Verbose output: Report all persistent fields for matching USM sessions"));
         verbosity.setRequired(false);
         opts.addOptionGroup(verbosity);
+        normalOpts.addOptionGroup(verbosity);
+        OptionGroup help = new OptionGroup();
+        help.addOption(new Option("h", "help", false, "Prints this help text"));
+        help.addOption(new Option("X", "examples", false, "Prints this help text with usage examples"));
+        opts.addOptionGroup(help);
+        helpOpts.addOptionGroup(help);
+        o = new Option("l", "login", true, "The optional JMX login (if JMX has authentication enabled)");
+        o.setArgName("login");
+        opts.addOption(o);
+        normalOpts.addOption(o);
+        o = new Option("p", "port", true, "The optional JMX port (default:9999)");
+        o.setArgName("port");
+        opts.addOption(o);
+        normalOpts.addOption(o);
+        o = new Option("s", "password", true, "The optional JMX password (if JMX has authentication enabled)");
+        o.setArgName("password");
+        opts.addOption(o);
+        normalOpts.addOption(o);
         toolOptions = opts;
+        normalOptions = normalOpts;
+        helpOptions = helpOpts;
     }
 
-    private static void printHelpAndExit() {
+    private static void printHelpAndExit(boolean addExamples) {
         HelpFormatter helpFormatter = new HelpFormatter();
-        helpFormatter.printHelp(
-            "usmsessions [USM-Request-URL-parameters or USM-Session-filter]+",
-            "",
-            toolOptions,
-            "Options -d,-e,-r are mutually exclusive, as are options -q,-v.\nArguments may be given as EAS-POST-URL-parameters, OLOX2-PUT-URL-parameters, or an USM-session-filter.\nAn USM-session-filter consists of 5 parts, separated by colon(\":\"):\nContext-ID:OX-User-ID:USM-Session-ID:USM-Protocol:Device-ID\nEach part may be left empty to match any value.\nEAS-Request-URLs are only specific to a device (so multiple sessions may be reported/affected for different users using that device).\nCurrently available USM-protocols are: EAS, JSON.\nExamples (from webserver-log):\nEAS: /Microsoft-Server-ActiveSync?Cmd=Sync&User=user&DeviceId=SomeDeviceId&DeviceType=Android\nEAS12: /Microsoft-Server-ActiveSync?eQAHBBCDDrY4vSg/QBtTxnnNJ1zwBGBI6k0LV2luZG93c01haWw=\nOLOX2:\n/usm-json/syncUpdate?id=SomeId");
+        helpFormatter.setOptionComparator(new Comparator<Option>() {
+
+            @Override
+            public int compare(Option o1, Option o2) {
+                int prioDiff = getOptionPriority(o1.getId()) - getOptionPriority(o2.getId());
+                return (prioDiff == 0) ? o1.getId() - o2.getId() : prioDiff;
+            }
+
+            private int getOptionPriority(int id) {
+                if (id == 'e')
+                    return -100;
+                if (id == 'r')
+                    return -90;
+                if (id == 'd')
+                    return -80;
+                if (id == 'q')
+                    return -70;
+                if (id == 'v')
+                    return -60;
+                if (id == 'h')
+                    return -50;
+                if (id == 'X')
+                    return -40;
+                if (id == 'l')
+                    return -30;
+                if (id == 'p')
+                    return -20;
+                if (id == 's')
+                    return -10;
+                return 0;
+            }
+        });
+        System.out.println(getUsageString(helpFormatter, helpOptions, false));
+        System.out.println(getUsageString(helpFormatter, normalOptions, true) + " (<Session-Filter>|<Request-Parameters>)+");
+        System.out.println();
+        System.out.println("Session-filter:      [<ContextID>]:[<UserID>]:[<Session-ID>]:[<Protocol>]:[<DeviceID>]");
+        System.out.println("Protocol:            (EAS|JSON)");
+        System.out.println("Request-Parameters:  <URL> or <URL-Parameters>");
+        System.out.println();
+        PrintWriter pw = new PrintWriter(System.out);
+        helpFormatter.printOptions(pw, _WIDTH, toolOptions, 1, 3);
+        pw.println();
+        helpFormatter.printWrapped(pw, _WIDTH, "Options -d,-e,-r are mutually exclusive, as are options -q,-v.");
+        pw.println();
+        helpFormatter.printWrapped(pw, _WIDTH, "Arguments may be given as Session-filter or Request-URL-parameters.");
+        pw.println();
+        helpFormatter.printWrapped(pw, _WIDTH, "Currently available protocols are EAS (Active Sync) and JSON (OX Connector for Outlook).");
+        helpFormatter.printWrapped(
+            pw,
+            _WIDTH,
+            "PLEASE NOTE: Enabling the EAS debug log for specific sessions is only possible for EAS sessions. If enabled, it logs communication data at level INFO. It does not enable logging of debug log messages at a higher level.");
+        if (addExamples) {
+            pw.println();
+            helpFormatter.printWrapped(pw, _WIDTH, "Examples:");
+            pw.println();
+            helpFormatter.printWrapped(pw, _WIDTH, "Show all active EAS sessions:");
+            pw.println("  # usmsessions :::EAS:");
+            pw.println();
+            helpFormatter.printWrapped(
+                pw,
+                _WIDTH,
+                "For a given Apache log entry, show the session information, including context-ID and user-ID of the accounts for which the requests were made. This may be useful in situations where a single client misbehaves and it is necessary to either disable that account or contact the end user for more information.");
+            helpFormatter.printWrapped(pw, _WIDTH, "EAS:");
+            pw.println("  # usmsessions \"Microsoft-Server-ActiveSync?Cmd=<SomeCommand>&User=<user>&DeviceId=<SomeDeviceId>&DeviceType=<SomeType>\"");
+            helpFormatter.printWrapped(pw, _WIDTH, "EAS12:");
+            pw.println("  # usmsessions \"Microsoft-Server-ActiveSync?<SomeBase64EncodedData>\"");
+            helpFormatter.printWrapped(pw, _WIDTH, "OLOX2:");
+            pw.println("  # usmsessions http://example.com/usm-json/syncUpdate?id=<SomeId>");
+            pw.println();
+            helpFormatter.printWrapped(
+                pw,
+                _WIDTH,
+                "Enable EAS debug logging for the session(s) of user 4 in context 1, with keyword \"mykeyword\":");
+            pw.println("  # usmsessions -e mykeyword 1:4:::");
+            pw.println();
+            helpFormatter.printWrapped(pw, _WIDTH, "Show all EAS sessions, stating for which ones EAS debug logging is enabled:");
+            pw.println("  # usmsessions -r :::EAS:");
+            pw.println();
+            helpFormatter.printWrapped(pw, _WIDTH, "Disable EAS debug logging for all sessions:");
+            pw.println("  # usmsessions -d ::::");
+            pw.println();
+        }
+        pw.flush();
         System.exit(0);
     }
 
+    private static String getUsageString(HelpFormatter formatter, Options options, boolean removeUsagePrefix) {
+        StringWriter sw = new StringWriter();
+        PrintWriter pw = new PrintWriter(sw);
+        formatter.printUsage(pw, 76, "usmsessions", options);
+        pw.flush();
+        String s = sw.toString().trim();
+        return removeUsagePrefix ? ("      " + s.substring(6)) : s;
+    }
+
     public static void main(String[] args) {
         new USMSessionTool(args).execute();
     }
@@ -159,8 +280,11 @@ public class USMSessionTool {
         CommandLine cmd;
         try {
             cmd = parser.parse(toolOptions, args);
+            if (cmd.hasOption('X')) {
+                printHelpAndExit(true);
+            }
             if (cmd.hasOption('h')) {
-                printHelpAndExit();
+                printHelpAndExit(false);
             }
             if (cmd.hasOption('l'))
                 _jmxLogin = CLToolsUtility.getOptionStringValue(cmd, 'l');
@@ -181,14 +305,14 @@ public class USMSessionTool {
             String[] data = cmd.getArgs();
             if (data == null || data.length == 0) {
                 System.err.println("No arguments specified");
-                printHelpAndExit();
+                printHelpAndExit(false);
             } else {
                 for (String entry : data)
                     _data.add(entry);
             }
         } catch (ParseException e) {
             System.err.println("Unable to parse command line: " + e.getMessage());
-            printHelpAndExit();
+            printHelpAndExit(false);
         }
     }
 
@@ -218,7 +342,7 @@ public class USMSessionTool {
         } catch (Exception e) {
             System.err.println("An error occurred while executing your request:");
             e.printStackTrace();
-            printHelpAndExit();
+            printHelpAndExit(false);
         }
     }
 
@@ -295,7 +419,7 @@ public class USMSessionTool {
             "getPropertiesOfAllSessions",
             params,
             signature);
-        List<JMXUSMSessionInfo> sessions = JMXUSMSessionInfo.fromJMXResult(result);
+        List<JMXUSMSessionInfo> sessions = JMXUSMSessionInfo.fromJMXResult(result, _quiet);
         for (JMXUSMSessionInfo session : sessions) {
             if (usmSessionId == 0 || session.getUsmSessionId() == usmSessionId) {
                 if (_verbose) {
