@@ -54,16 +54,15 @@ import java.util.BitSet;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.FolderContentType;
-import com.openexchange.usm.api.contenttypes.FolderContentTypeTransferHandler;
-import com.openexchange.usm.api.contenttypes.OXFolderContent;
-import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.folder.FolderContentType;
+import com.openexchange.usm.api.contenttypes.folder.OXFolderContent;
+import com.openexchange.usm.api.contenttypes.transferhandlers.FolderContentTypeTransferHandler;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.FolderNotFoundException;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
@@ -71,6 +70,10 @@ import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.OperationDeniedException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMIllegalArgumentException;
+import com.openexchange.usm.api.exceptions.UnsupportedContentOperationException;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
@@ -78,10 +81,6 @@ import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
 import com.openexchange.usm.contenttypes.util.OXErrorConstants;
 import com.openexchange.usm.contenttypes.util.USMContentTypesUtilErrorCodes;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
-import com.openexchange.usm.ox_json.OXJSONAccess;
 
 /**
  * @author ibr
@@ -92,8 +91,8 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 
     private static final String ALLOWED_MODULES = "allowed_modules";
 
-    public FolderContentTypeTransferHandlerImpl(FolderContentTypeImpl contentType, Log log, OXJSONAccess ajaxAccess) {
-        super(contentType, log, ajaxAccess);
+    public FolderContentTypeTransferHandlerImpl(FolderContentTypeImpl contentType, OXJSONAccess ajaxAccess) {
+        super(contentType, ajaxAccess);
     }
 
     @Override
@@ -110,19 +109,19 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
     public OXFolderContent readFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
         return new OXFolderContent(true, readFolderContent(folder, folder.getSession().getFieldFilter(folder.getContentType())));
     }
-    
+
     @Override
     public Folder[] readFolderContent(Folder folder, BitSet requestedFields) throws USMException {
         Session session = folder.getSession();
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " Read all " + _contentType.getID() + " in folder " + folder.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Read all " + _contentType.getID() + " in folder " + folder.getID());
         Map<String, String> parameters = createParametersWithAllowedModules(session, requestedFields);
-        parameters.put(UtilConstants.PARENT, folder.getID());
-        String errorOnDuplicateNamePersistentField = session.getPersistentField(UtilConstants.ERROR_ON_DUPLICATE_NAME_DB_FIELD);
+        parameters.put(CommonConstants.PARENT, folder.getID());
+        String errorOnDuplicateNamePersistentField = session.getPersistentField(CommonConstants.ERROR_ON_DUPLICATE_NAME_DB_FIELD);
         if (errorOnDuplicateNamePersistentField != null && errorOnDuplicateNamePersistentField.length() > 0)
-            parameters.put(UtilConstants.ERROR_ON_DUPLICATE_NAME, errorOnDuplicateNamePersistentField);
+            parameters.put(CommonConstants.ERROR_ON_DUPLICATE_NAME, errorOnDuplicateNamePersistentField);
         addObjectsLimitParameters(session, parameters);
-        DataObject[] listOfResults = performActionAndCheckRights(UtilConstants.ACTION_LIST, folder, requestedFields, parameters);
+        DataObject[] listOfResults = performActionAndCheckRights(CommonConstants.ACTION_LIST, folder, requestedFields, parameters);
         Folder[] result = tranformToFolders(listOfResults);
         for (Folder f : result) {
             if (f != null)
@@ -134,15 +133,15 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
     @Override
     public Folder[] readUpdatedFolderContent(Folder folder, BitSet requestedFields, long timestamp) throws USMException {
         Session session = folder.getSession();
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " Read updated " + _contentType.getID() + " after " + timestamp + " in folder " + folder.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Read updated " + _contentType.getID() + " after " + timestamp + " in folder " + folder.getID());
         Map<String, String> parameters = createParametersWithAllowedModules(session, requestedFields);
-        parameters.put(UtilConstants.PARENT, folder.getID()); // object ID of the folder
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
+        parameters.put(CommonConstants.PARENT, folder.getID()); // object ID of the folder
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(timestamp));
         return tranformToFolders(getListOfUpdates(
             folder,
             requestedFields,
-            _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_UPDATES, session, parameters)));
+            _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_UPDATES, session, parameters)));
     }
 
     @Override
@@ -160,14 +159,15 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
         writeUpdatedFolder(checkContentType(object), timestamp);
     }
 
+    @Override
     public void readFolder(Folder object, BitSet requestedFields) throws USMException {
         Session session = object.getSession();
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " Get folder" + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Get folder" + object.getID());
         // Build parameter list
         Map<String, String> parameters = createCommonParameters(session, requestedFields);
-        parameters.put(UtilConstants.ID, object.getID());
-        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_GET, session, parameters);
+        parameters.put(CommonConstants.ID, object.getID());
+        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_GET, session, parameters);
         if (result.getResultType() == JSONResultType.Error) {
             checkConflictingChange(result.getJSONObject());
             checkAuthenticationFailed(result.getJSONObject());
@@ -181,9 +181,9 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 
     protected void checkAuthenticationFailed(JSONObject errorObject) throws InternalUSMException, AuthenticationFailedException {
         try {
-            int category = errorObject.optInt(UtilConstants.CATEGORY);
-            String message = errorObject.getString(UtilConstants.ERROR);
-            String code = errorObject.getString(UtilConstants.CODE);
+            int category = errorObject.optInt(CommonConstants.CATEGORY);
+            String message = errorObject.getString(CommonConstants.ERROR);
+            String code = errorObject.getString(CommonConstants.CODE);
             if (category == OXErrorConstants.CATEGORY_PERMISSION && OXErrorConstants.MSG_1000.equals(code)) {
                 throw new AuthenticationFailedException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER15, message, errorObject);
             }
@@ -197,19 +197,20 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
     private void addTreeParameter(Session session, Map<String, String> parameters) {
         String folderTree = session.getPersistentField(FolderContentType.FOLDER_TREE);
         if (folderTree != null && folderTree.length() > 0)
-            parameters.put(UtilConstants.TREE, folderTree);
+            parameters.put(CommonConstants.TREE, folderTree);
     }
 
+    @Override
     public void writeDeletedFolder(Folder object) throws USMException {
         Session session = object.getSession();
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " Delete folder " + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Delete folder " + object.getID());
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
         addTreeParameter(session, parameters);
         JSONArray array = new JSONArray();
         array.put(object.getID());
-        JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_DELETE, session, parameters, array);
+        JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_DELETE, session, parameters, array);
         if (result.getResultType() == JSONResultType.Error)
             throw new OperationDeniedException(USMContentTypesFolderErrorCodes.FOLDER_DELETION_DENIED_BY_OX, result.getJSONObject());
         // Do not use normal method to check for temporary failed deletions, since also fatal errors are reported for folder deletions that
@@ -219,20 +220,21 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
             throw new USMException(USMContentTypesFolderErrorCodes.FOLDER_DELETION_FAILED_IN_OX, "Folder deletion failed in OX server");
     }
 
+    @Override
     public void writeNewFolder(Folder object) throws USMException {
         Session session = object.getSession();
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " Create folder " + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Create folder " + object.getID());
         checkIDLength(object);
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.PARENTFOLDER_ID, object.getParentFolderID());
+        parameters.put(CommonConstants.PARENTFOLDER_ID, object.getParentFolderID());
         addTreeParameter(session, parameters);
         JSONObject requestBody = createRequestBody(object, false, true);
-        JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_NEW, session, parameters, requestBody);
+        JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_NEW, session, parameters, requestBody);
         checkResult(result, JSONResultType.JSONObject);
         JSONObject o = result.getJSONObject();
         try {
-            object.setID(o.getString(UtilConstants.RESULT_DATA));
+            object.setID(o.getString(CommonConstants.RESULT_DATA));
         } catch (JSONException e) {
             throw new OXCommunicationException(
                 USMContentTypesUtilErrorCodes.ID_NOT_PRESENT_NUMBER2,
@@ -255,16 +257,18 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
         return id.length() > FOLDER_ID_LENGTH_LIMIT;
     }
 
+    @Override
     public void writeUpdatedFolder(Folder object, long timestamp) throws USMException {
         checkIDLength(object);
         writeStandardUpdateDataObject(object, timestamp, true);
     }
 
+    @Override
     public Folder[] readRootFolders(Session session, BitSet requestedFields) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(session + " Get root folders");
+        if (LOG.isDebugEnabled())
+            LOG.debug(session + " Get root folders");
         Map<String, String> parameters = createParametersWithAllowedModules(session, requestedFields);
-        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ROOT, session, parameters);
+        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_ROOT, session, parameters);
         checkResult(result, JSONResultType.JSONObject);
         Folder[] folders = tranformToFolders(getListOfResults(
             ((FolderContentType) _contentType).newDataObject(session),
@@ -279,7 +283,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
     private Map<String, String> createCommonParameters(Session session, BitSet requestedFields) throws UnsupportedContentOperationException {
         Map<String, String> parameters = new HashMap<String, String>();
         addTreeParameter(session, parameters);
-        parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
+        parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
         return parameters;
     }
 
@@ -324,6 +328,7 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
                 if (module.equals(DefaultContentTypes.TASK_ID) || module.equals(DefaultContentTypes.MAIL_ID) || module.equals(DefaultContentTypes.CALENDAR_ID) || module.equals(DefaultContentTypes.CONTACTS_ID) || module.equals(MODULE_SYSTEM))
                     list.add(f);
             } catch (Exception ignored) {
+                // ignore
             }
         }
         return list.toArray(new Folder[list.size()]);
@@ -337,11 +342,11 @@ public class FolderContentTypeTransferHandlerImpl extends AbstractTransferHandle
 
     @Override
     protected String getOXAjaxAccessPath() {
-        return UtilConstants.FOLDER_PATH;
+        return CommonConstants.FOLDER_PATH;
     }
 
     @Override
-    protected boolean hasFolderReadRights(Folder folder) throws USMException {
+    protected boolean hasFolderReadRights(Folder folder) {
         return true;
     }
 }
