@@ -371,6 +371,17 @@ public abstract class BaseCommandHandler implements CommandHandler {
         }
     }
 
+    protected long getLong(JSONArray o, int index) throws USMJSONAPIException {
+        try {
+            return o.getLong(index);
+        } catch (JSONException e) {
+            throw new USMJSONAPIException(
+                ConnectorBundleErrorCodes.COMMAND_NO_LONG_IN_JSON_ARRAY,
+                ResponseStatusCode.WRONG_MISSING_PARAMETERS,
+                "No long for index " + index);
+        }
+    }
+
     protected int getInt(JSONObject o, String key) throws USMJSONAPIException {
         try {
             return o.getInt(key);
