@@ -63,6 +63,7 @@ import com.openexchange.usm.api.contenttypes.contact.ContactContentType;
 import com.openexchange.usm.api.contenttypes.mail.MailContentType;
 import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.database.StorageAccessException;
+import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
@@ -85,7 +86,7 @@ import com.openexchange.usm.util.Toolkit;
 /**
  * {@link DownloadDataHandler} Sends Mail and PIM attachments to the client. Directly streams the data provided by the request to the OX
  * server to the HttpResponse of the client request
- * 
+ *
  * @author <a href="mailto:afe@microdoc.de">Alexander Feess</a>
  */
 public class DownloadDataHandler extends NormalCommandHandler {
@@ -186,11 +187,21 @@ public class DownloadDataHandler extends NormalCommandHandler {
                 data.put(MORE_AVAILABLE, true);
             return new ResponseObject(_responseStatus, data);
         } catch (USMException e) {
+            if (e instanceof OXCommunicationException && ((OXCommunicationException)e).getHttpStatusCode() == 406) {
+                _servlet.getJournal().debug("image not available for " + _id + "  " + e.getErrorMessage());
+                JSONObject data = new JSONObject();
+                try {
+                    data.put("data", "");
+                }
+                catch (JSONException ej) {
+                    // ignore
+                }
+                return new ResponseObject(ResponseStatusCode.SUCCESS, data);                
+            }
             throw new USMJSONAPIException(
                 ConnectorBundleErrorCodes.DOWNLOAD_DATA_IMAGE_NOT_FOUND,
                 ResponseStatusCode.WRONG_MISSING_PARAMETERS,
-                "Image not found for '" + _id + '\'',
-                e);
+                "Image not found for '" + _id + '\'', e);
         } catch (JSONException e) {
             throw USMJSONAPIException.createJSONError(ConnectorBundleErrorCodes.DOWNLOAD_DATA_JSON_ERROR, e);
         }
@@ -198,7 +209,7 @@ public class DownloadDataHandler extends NormalCommandHandler {
 
     private void skipOffset(ResourceInputStream is) throws IOException {
         long skipped =0L, remaining = _offset;
-        
+
         for (; remaining > 0; remaining -= skipped) {
             skipped = is.skip(remaining);
             if (skipped <= 0) {
@@ -312,7 +323,7 @@ public class DownloadDataHandler extends NormalCommandHandler {
             String key = generateKeyFor(_session.getUser(), _session.getProtocol(), _session.getDevice());
             String tempId = (String) _session.getCustomProperty(key + "_id");
             String contentType = (String) _session.getCustomProperty(key + "_ct");
-            
+
             if (_offset == 0) {
                 // read data once into a temporary file
                 tempId = UUID.randomUUID().toString();
@@ -399,21 +410,21 @@ public class DownloadDataHandler extends NormalCommandHandler {
         return new StringBuilder(128).append("__file_").append(user).append('_').append(protocol).append('_').append(device).toString();
     }
 
-    
+
     /**
      * {@link TempFileResourceInputStream} Allows access to data stored in a temporary file for subsequent downloadData commands
-     * 
+     *
      * @authors <a href="mailto:mgr@microdoc.de">Max Griessl</a>, <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
      */
     private static class TempFileResourceInputStream extends ResourceInputStream {
-    
+
             private InputStream _in;
             private final String _contentType;
             private final long _contentLength;
             private final boolean _deleteOnClose;
             private final String _tempId;
             private final Session _session;
-    
+
             TempFileResourceInputStream(TempFile file, String tempId, Session session, String contentType, boolean deleteOnClose) throws IOException {
                 super();
                 _deleteOnClose = deleteOnClose;
@@ -423,41 +434,41 @@ public class DownloadDataHandler extends NormalCommandHandler {
                 _contentType = contentType;
                 _session = session;
             }
-    
+
             private void ensureOpen() throws IOException {
                 if (null == _in) {
                     throw new IOException("Stream already closed");
                 }
             }
-    
+
             @Override
             public long getContentLength() {
                 return _contentLength;
             }
-    
+
             @Override
             public String getContentType() {
                 return _contentType;
             }
-    
+
             @Override
             public int read() throws IOException {
                 ensureOpen();
                 return _in.read();
             }
-    
+
             @Override
             public int read(byte[] b) throws IOException {
                 ensureOpen();
                 return _in.read(b);
             }
-    
+
             @Override
             public int read(byte[] b, int off, int len) throws IOException {
                 ensureOpen();
                 return _in.read(b, off, len);
             }
-    
+
             @Override
             public void close() throws IOException {
                 InputStream in = _in;
@@ -470,19 +481,19 @@ public class DownloadDataHandler extends NormalCommandHandler {
                 }
                 super.close();
             }
-    
+
             @Override
             public long skip(long n) throws IOException {
                 ensureOpen();
                 return _in.skip(n);
             }
-    
+
             @Override
             public int available() throws IOException {
                 ensureOpen();
                 return _in.available();
             }
-    
+
             @Override
             public void mark(int readlimit) {
                 InputStream in = this._in;
@@ -490,13 +501,13 @@ public class DownloadDataHandler extends NormalCommandHandler {
                     in.mark(readlimit);
                 }
             }
-    
+
             @Override
             public void reset() throws IOException {
                 ensureOpen();
                 _in.reset();
             }
-    
+
             @Override
             public boolean markSupported() {
                 InputStream in = this._in;
