@@ -77,7 +77,10 @@ import com.openexchange.usm.session.dataobject.DataObjectSet;
 
 public class InvalidateObjectsHandler extends NormalCommandHandler {
 
-	private static final String NOT_FOUND = "not found";
+	private static final String OBJECTS = "objects";
+    private static final String OK = "ok";
+    private static final String CHILDONLY = "childrenonly";
+    private static final String NOT_FOUND = "not found";
 	private static final String[] REQUIRED_PARAMETERS = { SESSIONID, SYNCID };
 	private static final String[] OPTIONAL_PARAMETERS = { FOLDERID, OBJECTIDS };
 
@@ -101,6 +104,7 @@ public class InvalidateObjectsHandler extends NormalCommandHandler {
 				objects = _session.getCachedFolders(syncID);
 				invalidatingFolders = true;
 			} else {
+			    //invalidating objects in a given folder
 				try {
 					Folder folder = getFolderByUUID(folderUUID);
 					folderID = folder.getID();
@@ -108,27 +112,49 @@ public class InvalidateObjectsHandler extends NormalCommandHandler {
 				} catch (USMJSONAPIException e) {
 					resultData.put(folderUUID, NOT_FOUND);
 					JSONObject response = new JSONObject();
-					response.put("syncid", syncID);
-					response.put("objects", resultData);
+					response.put(SYNCID, syncID);
+					response.put(OBJECTS, resultData);
 					return new ResponseObject(ResponseStatusCode.BAD_REQUEST, response, ConnectorBundleErrorCodes.UUID_DOES_NOT_EXIST, "No object found for UUID " + folderUUID, null, null, e);
 				}
 			}
+			
 			DataObjectSet objectsSet = new DataObjectSet(objects);
 			int length = objectUUIDs.length();
 			for (int i = 0; i < length; i++) {
 				String uuid = objectUUIDs.getString(i);
-				DataObject removedObj = objectsSet.remove(UUID.fromString(uuid));
-				resultData.put(uuid, (removedObj == null) ? NOT_FOUND : "ok");
-				if(invalidatingFolders)
+				boolean removeOnlyChildren = uuid.endsWith(CHILDONLY);
+				
+				DataObject removedObj = null;
+				
+				if (!removeOnlyChildren) {
+				   removedObj = objectsSet.remove(UUID.fromString(uuid));
+				} else {
+				   uuid = uuid.substring(0, uuid.indexOf(":"));
+				   removedObj = objectsSet.get(UUID.fromString(uuid));
+				}
+				resultData.put(uuid, (removedObj == null) ? NOT_FOUND : OK);
+				
+				if (invalidatingFolders && removedObj != null) { //remove the subfolders from the synced state
 				    removeSubfoldersFromSyncedFoldersSet(removedObj, objectsSet, new DataObjectSet(objectsSet));
+				}
+				
+				if (invalidatingFolders && removeOnlyChildren && removedObj != null) { //invalidate all children objects 
+				    long newestTimestamp = _session.getNewestTimestamp(removedObj.getID());
+				    _session.storeSyncState(newestTimestamp, newestTimestamp, new DataObjectSet().toArray()); //save a empty object set for the newest known timestamp
+				    _session.invalidateCachedData(removedObj.getID());
+				}
 			}
-			long newSyncID = (folderUUID == null) ? _session.storeSyncState(syncID, syncID, objectsSet.toArray())
+			_session.invalidateCachedData(folderID); //invalidates the cashed data and marks the folder as dirty; for folderID = null -folderHierarchy
+			long newSyncID = (invalidatingFolders) ? _session.storeSyncState(syncID, syncID, objectsSet.toArray())
 					: _session.storeSyncState(syncID, syncID, folderID, objectsSet.toArray());
+			
+			//create the response
 			JSONObject response = new JSONObject();
-			response.put("syncid", newSyncID);
-			response.put("objects", resultData);
+			response.put(SYNCID, newSyncID);
+			response.put(OBJECTS, resultData);
 			logSyncData(" invalidateObjects", folderUUID, syncID, newSyncID, 0L);
 			return new ResponseObject(ResponseStatusCode.SUCCESS, response);
+			
 		} catch (StorageAccessException e) {
 			throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.INVALIDATE_OBJECTS_DB_ERROR, e);
 		} catch (USMStorageException e) {
