@@ -69,7 +69,6 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.mail.MailContentType;
 import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.OperationDeniedException;
 import com.openexchange.usm.api.exceptions.USMException;
@@ -250,7 +249,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
                 }
             }
 
-            if (DefaultContentTypes.MAIL_CODE == destinationFolder.getElementsContentType().getCode() || DefaultContentTypes.MAIL_ID.equals(destinationFolder.getElementsContentTypeID())) { // for mail folders we still have to modify the last sync states - otherwise the mail will be duplicated at the destination
+            // for the destination folder save and modify the new sync state - generates new desinationsyncid
                 DataObject[] newDestinationState = getNewDestinationStateToSave(destinationFolder, changesList, updateErrorsMap);
                 long newestTimestamp = _session.getNewestTimestamp(destinationFolder.getID());
                 long newDestinationSyncID = _session.storeSyncState(
@@ -259,7 +258,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
                     destinationFolder.getID(),
                     newDestinationState);
                 responseData.put(DESTINATIONSYNCID, newDestinationSyncID);
-            }
+
 
 			initializeErrorMap(updateErrorsMap);
 
