@@ -424,6 +424,15 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         return isAppointmentException(dataObject);
     }
 
+    protected static boolean isFolder(DataObject dataObject) {
+        if(dataObject == null)
+            return false;
+        ContentType contentType = dataObject.getContentType();
+        if (contentType == null || contentType.getCode() != DefaultContentTypes.FOLDER_CODE)
+            return false;
+        return true;
+    }
+
     protected void addOptionalFolderUUID(DataObject o, JSONObject object) throws USMJSONAPIException, JSONException {
         if (object.has(FOLDER_ID)) {
             initAllFolders();
