@@ -48,18 +48,13 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.DEVICE;
-import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_ID;
-import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_UUID;
-import static com.openexchange.usm.connector.commands.CommandConstants.OBJECTIDS;
-import static com.openexchange.usm.connector.commands.CommandConstants.OBJECT_UUIDS;
-import static com.openexchange.usm.connector.commands.CommandConstants.PASSWORD;
-import static com.openexchange.usm.connector.commands.CommandConstants.USER;
+import static com.openexchange.usm.connector.commands.CommandConstants.*;
 import java.util.UUID;
 import javax.servlet.http.HttpServletRequest;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.usm.api.exceptions.TemporaryDownOrBusyException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
@@ -135,7 +130,9 @@ public class ResolveIDsHandler extends BaseCommandHandler {
 		} catch (IllegalArgumentException e) {
 			throw new USMJSONAPIException(ConnectorBundleErrorCodes.RESOLVE_IDS_INVALID_UUID,
 					ResponseStatusCode.WRONG_MISSING_PARAMETERS, "Invalid UUID", e);
-		} catch (USMException e) {
+        } catch (TemporaryDownOrBusyException e) {
+            throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.RESOLVE_IDS_TEMPORARY_DOWN_OR_BUSY, e);
+        } catch (USMException e) {
 			throw new USMJSONAPIException(ConnectorBundleErrorCodes.RESOLVE_IDS_LOGIN_UNSUCCESSFUL,
 					ResponseStatusCode.ACCESS_DENIED, "Can not login.", e);
 		} catch (JSONException e) {
