@@ -86,6 +86,8 @@ public class JSONSessionInitializer implements SessionInitializer {
 
     private static final String[] RELEVANT_MAIL_FIELDS = { "id", "folder_id", "flags", "color_label" };
 
+    private static final String[] INVALID_FOLDER_FIELDS = { "total", "new", "unread", "deleted"};
+
     private static ContactSorter _contactSorter;
 
     private static MailSorter _mailSorter;
@@ -116,6 +118,15 @@ public class JSONSessionInitializer implements SessionInitializer {
             }
             activateInternalFields(fieldSet, fields);
         }
+        if (DefaultContentTypes.FOLDER_ID.equals(type.getID())) {
+            ContentTypeField[] fields = type.getFields();
+            for (int i = fieldSet.nextSetBit(0); i >= 0; i = fieldSet.nextSetBit(i + 1)) {
+                if (isExcludedField(fields[i].getFieldName(), INVALID_FOLDER_FIELDS)) {
+                    excluded = true;
+                    fieldSet.clear(i);
+                }
+            }
+        }
         return excluded;
     }
 
