@@ -50,16 +50,16 @@ package com.openexchange.usm.json;
 
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.database.DatabaseAccessException;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.FolderNotFoundException;
+import com.openexchange.usm.api.exceptions.InvalidUUIDException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.TemporaryDownOrBusyException;
 import com.openexchange.usm.api.exceptions.USMAccessDeniedException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.connector.exceptions.DataObjectNotFoundException;
-import com.openexchange.usm.connector.exceptions.InvalidUUIDException;
 import com.openexchange.usm.connector.exceptions.MultipleOperationsOnDataObjectException;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 
@@ -80,7 +80,7 @@ public class USMJSONAPIException extends USMException {
 			code = ResponseStatusCode.TEMPORARY_NOT_AVAILABLE;
 		else if (cause instanceof OXCommunicationException)
 			code = ResponseStatusCode.OX_SERVER_ERROR;
-		else if (cause instanceof DatabaseAccessException || cause instanceof USMSQLException)
+		else if (cause instanceof StorageAccessException || cause instanceof USMStorageException)
 			code = ResponseStatusCode.DATABASE_ERROR;
 		else if (cause instanceof FolderNotFoundException)
 			code = ResponseStatusCode.FOLDER_NOT_FOUND;
