@@ -69,9 +69,9 @@ public final class USMJSONVersion {
     /**
      * USM JSON versions
      */
-    public static final String VERSION = "7.6.2-16";
+    public static final String VERSION = "7.6.3-2";
 
-    public static final String BUILD_NUMBER = "1bdd09971697e892e30b2773967e35ccf014dbed- 6788";
+    public static final String BUILD_NUMBER = "781e738d5f61225e3d5285404efd12571b0ad5ba- 6894";
 
     public static final String _CLIENT_USM_JSON_VERSION_KEY = "json.Prot.Version";
 
@@ -81,11 +81,13 @@ public final class USMJSONVersion {
 
     public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING = new USMJSONVersion("2.2.0");
     
+    public static final USMJSONVersion SUPPORTS_STANDARD_FOLDER_SWAPPING = new USMJSONVersion("2.3.0");
+    
     public static final USMJSONVersion SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754 = new USMJSONVersion("2.1.0");
 
     private static final USMJSONVersion _CURRENT_VERSION = _SUPPORTS_FILTERED_OUT_LARGE_OBJECTS_STATUS_CODE;
 
-    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_CONTACT_IMAGE_STREAMING;
+    private static final USMJSONVersion _NEWEST_VERSION = SUPPORTS_STANDARD_FOLDER_SWAPPING;
 
     private static final List<USMJSONVersion> _supportedVersions = new ArrayList<USMJSONVersion>();
 
@@ -93,6 +95,7 @@ public final class USMJSONVersion {
         if (_supportedVersions.isEmpty()) {
             synchronized (_supportedVersions) {
                 if (_supportedVersions.isEmpty()) {
+                    _supportedVersions.add(SUPPORTS_STANDARD_FOLDER_SWAPPING);
                     _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING);
                     _supportedVersions.add(SUPPORTS_CONTACT_IMAGE_STREAMING_FALSE_33754);
                     _supportedVersions.add(SUPPORTS_ATTACHMENT_STREAMING);
@@ -149,6 +152,10 @@ public final class USMJSONVersion {
         return !getUsedVersion(session).isOlder(SUPPORTS_CONTACT_IMAGE_STREAMING.getVersion(), 3);
     }
 
+    public static boolean supportsStandardFolderSwapping(Session session) {
+        return !getUsedVersion(session).isOlder(SUPPORTS_STANDARD_FOLDER_SWAPPING.getVersion(), 3);
+    }
+
     public static Version getUsedVersion(Session session) {
         return Version.fromString(session.getPersistentField(_CLIENT_USM_JSON_VERSION_KEY));
     }
