@@ -60,13 +60,13 @@ import com.openexchange.usm.json.USMJSONAPIException;
  */
 public class ResponseObject extends JSONObject {
 
-	private static final String DATA = "data";
-	private static final String STATUS = "status";
-	private static final String ERROR_CODE = "errorCode";
+	public static final String DATA = "data";
+	public static final String STATUS = "status";
+	public static final String ERROR_CODE = "errorCode";
 	public static final String ERROR_MESSAGE = "errorMessage";
 	public static final String ERROR_DETAILS = "errorDetails";
 	public static final String ERROR_STATUS = "errorStatus";
-	private static final String OX_ERROR = "oxError";
+	public static final String OX_ERROR = "oxError";
 
 	private final ResponseStatusCode _status;
 	private final Object _data;
