@@ -48,7 +48,6 @@
  */
 package com.openexchange.usm.mimemail;
 
-import javax.mail.MessagingException;
 import javax.mail.Session;
 import javax.mail.internet.MimeMessage;
 
@@ -69,5 +68,5 @@ public class USMMimeMessage extends MimeMessage implements OutputStreamWriter {
 	protected void updateMessageID() {
 		//The superclass MimeMessage updates always the Header Message-ID 
     	//with own generated Unique - identifier. It will be not different, if the Message-Id Header was already set or not.
-	}	
+	}
 }
