@@ -59,6 +59,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.UUID;
 import java.util.concurrent.TimeUnit;
+
 import org.apache.commons.httpclient.Header;
 import org.apache.commons.httpclient.HttpClient;
 import org.apache.commons.httpclient.HttpException;
@@ -90,6 +91,7 @@ import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+
 import com.openexchange.usm.api.USMVersion;
 import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
@@ -183,8 +185,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
      * @param performStaleChecking
      * @param passHostHeaderFromClient
      */
-    public OXJSONAccessImpl(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
-        String error = doActivate(oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes);
+    public OXJSONAccessImpl(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
+        String error = doActivate(oxJSONURL, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
         if (error != null) {
             error = "OXJSONAccess not activated, reason: " + error;
             LOG.error(error);
@@ -413,7 +415,7 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         deactivate("USM OXJSONAccess deactivated");
     }
 
-    private String doActivate(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes) {
+    private String doActivate(String oxJSONURL, int maxConnections, int connectionTimeout, boolean performStaleChecking, boolean passHostHeaderFromClient, String reloginErrorCodes, String missingObjectErrorCodes) {
         _oxJSONBaseURLasString = oxJSONURL;
         _passClientHostHeader = passHostHeaderFromClient;
         try {
@@ -421,7 +423,8 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         } catch (URIException e) {
             return "OXJSONAccess base URL is no valid http(s) URL: " + _oxJSONBaseURLasString;
         }
-        OXJSONSupport.setReloginErrorCodes(reloginErrorCodes);
+        OXJSONUtil.setReloginErrorCodes(reloginErrorCodes);
+        OXJSONUtil.setMissingObjectErrorCodes(missingObjectErrorCodes);
         _connectionTimeout = connectionTimeout;
         _httpManager = new MultiThreadedHttpConnectionManager();
         HttpConnectionManagerParams httpParams = _httpManager.getParams();
