@@ -101,7 +101,10 @@ public class OXJSONAccessActivator extends AbstractUSMActivator {
             String reloginErrorCodes = cm.getProperty(
                 ConfigurationProperties.OX_ACCESS_RELOGIN_ERROR_CODES_PROPERTY,
                     ConfigurationProperties.OX_ACCESS_RELOGIN_ERROR_CODES_DEFAULT, false);
-            OXJSONAccess jsonAccess = new OXJSONAccessImpl(accessUrl, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes);
+            String missingObjectErrorCodes = cm.getProperty(
+                    ConfigurationProperties.OX_ACCESS_MISSING_OBJECT_ERROR_CODES_PROPERTY,
+                        ConfigurationProperties.OX_ACCESS_MISSING_OBJECT_ERROR_CODES_DEFAULT, false);
+            OXJSONAccess jsonAccess = new OXJSONAccessImpl(accessUrl, maxConnections, connectionTimeout, performStaleChecking, passHostHeaderFromClient, reloginErrorCodes, missingObjectErrorCodes);
             registerService(OXJSONAccess.class, jsonAccess);
             LOG.info("OXJSONAccess registered.");
         } catch (USMInvalidConfigurationException e) {
