@@ -52,6 +52,7 @@ package com.openexchange.usm.session.dataobject;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -315,4 +316,22 @@ public class DataObjectSet implements Collection<DataObject> {
     public Set<String> getIDs() {
         return _idMap.keySet();
     }
+    
+    public void swapUUIDs(Map<UUID, UUID> swapUUIDsMap) {
+        Set<UUID> processedSwapUuids = new HashSet<UUID>();
+        for (UUID uuid1: swapUUIDsMap.keySet()) {
+            UUID uuid2 = swapUUIDsMap.get(uuid1);
+            if (!uuid1.equals(uuid2) && uuid2 != null && !processedSwapUuids.contains(uuid1) && contains(uuid1) && contains(uuid2)) {
+                DataObject obj1 = remove(uuid1);
+                DataObject obj2 = remove(uuid2);
+                DataObject copy1 = obj1.createCopy(false);
+                DataObject copy2 = obj2.createCopy(false);
+                copy1.setUUID(uuid2);
+                copy2.setUUID(uuid1);
+                add(copy1);
+                add(copy2);
+                processedSwapUuids.add(uuid2);
+            }
+        }
+    }
 }
