@@ -56,15 +56,15 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.usm.api.USMDebugConstants;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.exceptions.DeserializationFailedException;
-import com.openexchange.usm.api.session.ChangeState;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.ProtocolInformation;
 import com.openexchange.usm.api.session.Session;
+import com.openexchange.usm.api.session.assets.ChangeState;
 
 /**
  * Base implementation of DataObject. It stores ID and ParentFolderID directly in
@@ -158,112 +158,137 @@ public class SimpleDataObject implements DataObject {
 		}
 	}
 
-	public Session getSession() {
+	@Override
+    public Session getSession() {
 		return _session;
 	}
 
-	public ContentType getContentType() {
+	@Override
+    public ContentType getContentType() {
 		return _contentType;
 	}
 
-	public ChangeState getChangeState() {
+	@Override
+    public ChangeState getChangeState() {
 		return _changeState;
 	}
 
-	public void setChangeState(ChangeState newState) {
+	@Override
+    public void setChangeState(ChangeState newState) {
 		if (newState != ChangeState.CREATED && newState != ChangeState.DELETED)
 			throw new IllegalArgumentException("Changing from " + _changeState + " to " + newState + " not permitted");
 		_changeState = newState;
 	}
 
-	public String getID() {
+	@Override
+    public String getID() {
 		return convertObjectToString((getFieldContent(ID_INDEX)));
 	}
 
-	public String getOriginalID() {
+	@Override
+    public String getOriginalID() {
 		return convertObjectToString((getOriginalFieldContent(ID_INDEX)));
 	}
 
-	public void setID(String id) {
+	@Override
+    public void setID(String id) {
 		setFieldContent(ID_INDEX, id);
 	}
 
-	public long getTimestamp() {
+	@Override
+    public long getTimestamp() {
 		return _timestamp;
 	}
 
-	public long getOriginalTimestamp() {
+	@Override
+    public long getOriginalTimestamp() {
 		return _originalTimestamp;
 	}
 
-	public void setTimestamp(long timestamp) {
+	@Override
+    public void setTimestamp(long timestamp) {
 		_timestamp = timestamp;
 		updateChangeState(_timestamp != _originalTimestamp);
 	}
 
-	public String getParentFolderID() {
+	@Override
+    public String getParentFolderID() {
 		ensureCorrectParentFolderID();
 		return convertObjectToString((getFieldContent(PARENT_FOLDER_ID_INDEX)));
 	}
 
-	public String getOriginalParentFolderID() {
+	@Override
+    public String getOriginalParentFolderID() {
 		return convertObjectToString(getOriginalFieldContent(PARENT_FOLDER_ID_INDEX));
 	}
 
-	public void setParentFolderID(String folderID) {
+	@Override
+    public void setParentFolderID(String folderID) {
 		setFieldContent(PARENT_FOLDER_ID_INDEX, folderID);
 	}
 
-	public Object getFieldContent(int fieldIndex) {
+	@Override
+    public Object getFieldContent(int fieldIndex) {
 		return _fieldContent[fieldIndex];
 	}
 
-	public Object getOriginalFieldContent(int fieldIndex) {
+	@Override
+    public Object getOriginalFieldContent(int fieldIndex) {
 		return _originalFieldContent[fieldIndex];
 	}
 
-	public void setFieldContent(int fieldIndex, Object data) {
+	@Override
+    public void setFieldContent(int fieldIndex, Object data) {
 		_fieldContent[fieldIndex] = _contentType.getFields()[fieldIndex].getFieldType().checkValue(data);
 		if (fieldIndex == PARENT_FOLDER_ID_INDEX)
 			_parentFolder = null;
 		updateChangeState(fieldIndex);
 	}
 
-	public Object getFieldContent(String fieldName) {
+	@Override
+    public Object getFieldContent(String fieldName) {
 		return getFieldContent(getFieldIndex(fieldName));
 	}
 
-	public Object getOriginalFieldContent(String fieldName) {
+	@Override
+    public Object getOriginalFieldContent(String fieldName) {
 		return getOriginalFieldContent(getFieldIndex(fieldName));
 	}
 
-	public void setFieldContent(String fieldName, Object data) {
+	@Override
+    public void setFieldContent(String fieldName, Object data) {
 		setFieldContent(getFieldIndex(fieldName), data);
 	}
 
-	public void setParentFolder(Folder folder) {
+	@Override
+    public void setParentFolder(Folder folder) {
 		setParentFolderID(folder.getID());
 		_parentFolder = folder;
 	}
 
-	public Folder getParentFolder() {
+	@Override
+    public Folder getParentFolder() {
 		return _parentFolder;
 	}
 
-	public boolean isFieldModified(int fieldIndex) {
+	@Override
+    public boolean isFieldModified(int fieldIndex) {
 		return !_contentType.getFields()[fieldIndex].getFieldType().isEqual(_fieldContent[fieldIndex],
 				_originalFieldContent[fieldIndex]);
 	}
 
-	public boolean isFieldModified(String fieldName) {
+	@Override
+    public boolean isFieldModified(String fieldName) {
 		return isFieldModified(getFieldIndex(fieldName));
 	}
 
-	public boolean isModified() {
+	@Override
+    public boolean isModified() {
 		return _changeState != ChangeState.UNMODIFIED;
 	}
 
-	public void rollbackChanges() {
+	@Override
+    public void rollbackChanges() {
 		_parentFolder = null;
 		_timestamp = _originalTimestamp;
 		System.arraycopy(_originalFieldContent, 0, _fieldContent, 0, _fieldContent.length);
@@ -271,7 +296,8 @@ public class SimpleDataObject implements DataObject {
 		_failed = false;
 	}
 
-	public void commitChanges() {
+	@Override
+    public void commitChanges() {
 		ensureCorrectParentFolderID();
 		_originalTimestamp = _timestamp;
 		System.arraycopy(_fieldContent, 0, _originalFieldContent, 0, _fieldContent.length);
@@ -298,7 +324,8 @@ public class SimpleDataObject implements DataObject {
 		updateChangeState(isFieldModified(fieldIndex));
 	}
 
-	public int getFieldIndex(String fieldName) {
+	@Override
+    public int getFieldIndex(String fieldName) {
 		Integer index = _fieldNameToIndexMap.get(fieldName);
 		if (index != null)
 			return index;
@@ -319,11 +346,13 @@ public class SimpleDataObject implements DataObject {
 		return extended + toString(null, _skipUnsetValuesForToString);
 	}
 
-	public String toString(BitSet requestedFields) {
+	@Override
+    public String toString(BitSet requestedFields) {
 		return toString(requestedFields, _skipUnsetValuesForToString);
 	}
 
-	public String toString(BitSet requestedFields, boolean skipUnsetFields) {
+	@Override
+    public String toString(BitSet requestedFields, boolean skipUnsetFields) {
 		StringBuilder sb = new StringBuilder(1000);
 		sb.append(getDataObjectName()).append('(').append(_session).append(',').append(_contentType.getID())
 				.append(',').append(_changeState)/*.append(',').append(_uuid)*/.append("){");
@@ -425,13 +454,15 @@ public class SimpleDataObject implements DataObject {
 	 * Checks for equality without checking the ID. This test does *not* check if timestamps or attached ProtocolInformation is the same, those are ignored for the comparison !
 	 * 
 	 */
-	public boolean equalsWithoutID(DataObject other) {
+	@Override
+    public boolean equalsWithoutID(DataObject other) {
 		if (!(other instanceof SimpleDataObject))
 			return false;
 		return internalEquals((SimpleDataObject) other, true, true);
 	}
 	
-	public boolean equalsWithLastModified(DataObject other) {
+	@Override
+    public boolean equalsWithLastModified(DataObject other) {
         if (!(other instanceof SimpleDataObject))
             return false;
         return internalEquals((SimpleDataObject) other, false, false);
@@ -459,7 +490,8 @@ public class SimpleDataObject implements DataObject {
         return true;
     }
 
-	public DataObject createCopy(boolean linkUUIDs) {
+	@Override
+    public DataObject createCopy(boolean linkUUIDs) {
 		return new SimpleDataObject(this, linkUUIDs);
 	}
 
@@ -467,11 +499,13 @@ public class SimpleDataObject implements DataObject {
 		return (o == null) ? null : o.toString();
 	}
 
-	public boolean isFailed() {
+	@Override
+    public boolean isFailed() {
 		return _failed;
 	}
 
-	public void setFailed(boolean failed) {
+	@Override
+    public void setFailed(boolean failed) {
 		_failed = failed;
 	}
 
@@ -480,7 +514,8 @@ public class SimpleDataObject implements DataObject {
 			setParentFolder(_parentFolder);
 	}
 
-	public Serializable[] serialize() {
+	@Override
+    public Serializable[] serialize() {
 		ensureCorrectParentFolderID();
 		Serializable[] result = new Serializable[_fieldContent.length + 2];
 		ContentTypeField[] fields = _contentType.getFields();
@@ -493,7 +528,8 @@ public class SimpleDataObject implements DataObject {
 		return result;
 	}
 
-	public void deserialize(long timestamp, Serializable[] data) throws DeserializationFailedException {
+	@Override
+    public void deserialize(long timestamp, Serializable[] data) throws DeserializationFailedException {
 		_changeState = ChangeState.UNMODIFIED;
 		_timestamp = timestamp;
 		_originalTimestamp = timestamp;
@@ -518,18 +554,21 @@ public class SimpleDataObject implements DataObject {
 		System.arraycopy(_fieldContent, 0, _originalFieldContent, 0, _fieldContent.length);
 	}
 
-	public UUID getUUID() {
+	@Override
+    public UUID getUUID() {
 		return (_source == this) ? _uuid : _source.getUUID();
 	}
 
-	public void setUUID(UUID uuid) {
+	@Override
+    public void setUUID(UUID uuid) {
 		if (_source == this)
 			_uuid = uuid;
 		else
 			_source.setUUID(uuid);
 	}
 
-	public void linkUUIDTo(DataObject source) {
+	@Override
+    public void linkUUIDTo(DataObject source) {
 		if (source == null)
 			source = this;
 		if (source == this)
@@ -537,22 +576,26 @@ public class SimpleDataObject implements DataObject {
 		_source = source;
 	}
 
-	public ProtocolInformation getProtocolInformation() {
+	@Override
+    public ProtocolInformation getProtocolInformation() {
 		return (_source == this) ? _protocolInfo : _source.getProtocolInformation();
 	}
 
-	public void setProtocolInformation(ProtocolInformation info) {
+	@Override
+    public void setProtocolInformation(ProtocolInformation info) {
 		if (_source == this)
 			_protocolInfo = info;
 		else
 			_source.setProtocolInformation(info);
 	}
 
-	public int getParentFolderOwnerID() {
+	@Override
+    public int getParentFolderOwnerID() {
 		return _parentFolderOwnerID;
 	}
 
-	public void setParentFolderOwnerID(int id) {
+	@Override
+    public void setParentFolderOwnerID(int id) {
 		_parentFolderOwnerID = id;
 	}
 }
