@@ -372,7 +372,12 @@ public class SessionImpl implements Session {
         if (_sessionManager.isEmailPullEnabled() && contentType.getID().equals(DefaultContentTypes.MAIL_ID))
             _lastEmailFilter = filter;
         try {
-            _syncedFolderContent.put(folderId, 0L);
+            if (storeResult) {
+                // 0 is used as a flag that this folder is currently synced (to inform parallel running synchronizations)
+                // Example: parallel running ping and sync on different nodes
+                // (may happen if a client ignores cookies which are used by load balancers to delegate sessions onto one node) 
+                _syncedFolderContent.put(folderId, 0L);
+            }
             return _sessionManager.getIncrementalSyncer().syncChangesWithServer(
                 createFolderElementsStorage(folder, filter, storeResult, timestamp, resultLimit),
                 getConflictResolution(conflictResolution),
@@ -401,7 +406,8 @@ public class SessionImpl implements Session {
         if (_sessionManager.isEmailPullEnabled() && DefaultContentTypes.MAIL_ID.equals(folder.getElementsContentTypeID()))
             _lastEmailFilter = filter;
         try {
-            _syncedFolderContent.put(folderId, 0L);
+            if (storeResult)
+                _syncedFolderContent.put(folderId, 0L);
             return _sessionManager.getSlowSyncer().syncWithServer(
                 createFolderElementsStorage(folder, filter, storeResult, 0L, limit),
                 getConflictResolution(conflictResolution),
@@ -999,9 +1005,11 @@ public class SessionImpl implements Session {
                     if (journal.isDebugEnabled())
                         _sessionManager.getJournal().debug(
                             this + " Too many pings without sync, marked as synchronized: " + Arrays.toString(contentChangeParentIDsToWatch));
+                    // May happen e.g. if ping and sync run on different nodes and the ping request do not get the information that a sync request has already run 
                     for (String id : contentChangeParentIDsToWatch) {
                         _syncedFolderContent.put(id, 0L);
                     }
+                    return null;
                 }
                 return result;
             }
@@ -1043,17 +1051,34 @@ public class SessionImpl implements Session {
         return doWaitForChanges(watchFolderChanges, contentChangeParentIDsToWatch, end);
     }
 
-    private ObjectChanges performEmailPull(List<Folder> emailFolders) throws USMException {
+    private ObjectChanges performEmailPull(List<Folder> emailFolders) {
+        Log journal = _sessionManager.getJournal();
         List<String> changedFolders = new ArrayList<String>();
         for (Folder f : emailFolders) {
             String folderId = f.getID();
             Long timestamp = _syncedFolderContent.get(folderId);
-            if (timestamp == null || timestamp == 0L)
+            if (timestamp == null)
                 changedFolders.add(folderId);
             else {
-                SyncResult syncResult = syncChangesWithServer(folderId, timestamp, NO_LIMIT, _lastEmailFilter, false, null);
-                if (syncResult.getChanges().length > 0)
-                    changedFolders.add(folderId);
+                // if timestamp==0 probably sync and ping are running on different nodes or a ping and a sync are running parallel on the same node.
+                // In the first case we can not assure that the time window used to determine changes since the last sync is correct.
+                // Therefore we avoid the sync and belief on the normal event mechanism.
+                if (timestamp != 0L) {
+                    Long newestTimestamp = getNewestTimestamp(folderId);
+                    if (newestTimestamp != null && newestTimestamp != 0L) {
+                        try {
+                            SyncResult syncResult = syncChangesWithServer(folderId, newestTimestamp, NO_LIMIT, _lastEmailFilter, false, null);
+                            if (syncResult.getChanges().length > 0) {
+                                changedFolders.add(folderId);
+                                _syncedFolderContent.remove(folderId);
+                            }
+                        }
+                        catch (USMException e) {
+                            if (journal.isDebugEnabled())
+                                journal.debug(this + "sync within email pull failed: " + e.getMessage());
+                        }
+                    }
+                }
             }
         }
         return ObjectChangesImpl.create(false, changedFolders);
