@@ -675,7 +675,7 @@ public class SessionManagerImpl implements SessionManager {
         }
     }
 
-    public DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws StorageAccessException, USMStorageException {
+    public static DataObjectSet insertStoredUUID(DataObject o, DataObjectSet oldData, DataObjectSet newestCachedData) throws StorageAccessException, USMStorageException {
         boolean useModifiedUUID = o.getSession().getUserIdentifier() != o.getParentFolderOwnerID();
         if (oldData != null) {
             DataObject oldObject = oldData.get(o.getID());
@@ -690,8 +690,22 @@ public class SessionManagerImpl implements SessionManager {
             if (newestCachedData == null)
                 newestCachedData = new DataObjectSet(o.getSession().getCachedFolders());
             DataObject cachedFolder = newestCachedData.get(o.getID());
-            if (cachedFolder != null)
+            if (cachedFolder != null) {
+                if (oldData != null) {
+                    DataObject oldFolder = oldData.get(cachedFolder.getUUID());
+                    if (oldFolder != null) {
+                      if (!oldFolder.getID().equals(cachedFolder.getID()) && newestCachedData.get(oldFolder.getID()) != null) {
+                          // we have a swap situation
+                          DataObject swappedFolder = newestCachedData.get(oldFolder.getID());
+                          if (swappedFolder != null && swappedFolder.getUUID() != null) {
+                              o.setUUID(swappedFolder.getUUID());
+                              break;
+                          }
+                      }
+                    }
+                }
                 o.setUUID(cachedFolder.getUUID());
+            }
             break;
         case DefaultContentTypes.MAIL_CODE:
             if (newestCachedData == null)
