@@ -90,6 +90,61 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 	public SyncResult syncChangesWithServer(ContentSyncerStorage storage, ConflictResolution conflictResolution,
 			DataObject[] lastSyncState, DataObject[] dataObjectChanges, long timestamp, int resultLimit,
 			DataObjectFilter filter, Comparator<? super DataObject> sorter) throws USMException {
+	    
+	    if (_journal.isTraceEnabled()) {
+	        String lastSyncObjects = "";
+	        String clientChanges = "";
+	        if (lastSyncState != null) {
+	            for (DataObject f : lastSyncState) {
+	                if (f.getChangeState() != ChangeState.UNMODIFIED)
+	                    lastSyncObjects += "presync: lastSyncState " + f.toString() + "\n"; 
+	            }
+	        }
+            if (dataObjectChanges != null) {
+                for (DataObject f : dataObjectChanges) {
+                    if (f.getChangeState() != ChangeState.UNMODIFIED)
+                        clientChanges += "presync: clientChange " + f.toString() + "\n"; 
+                }
+            }
+	    
+            if (!lastSyncObjects.isEmpty() || !clientChanges.isEmpty())
+                _journal.trace(lastSyncObjects + clientChanges);
+	    }
+
+
+	    SyncResult result = syncChangesWithServerCore(storage, conflictResolution,
+            lastSyncState, dataObjectChanges, timestamp, resultLimit, filter, sorter);
+
+
+	    if (_journal.isTraceEnabled()) {
+            String newSyncObjects = "";
+            String changes = "";
+            DataObject[] newSyncState = result.getNewState();
+            DataObject[] changedObjects = result.getChanges();
+            if (newSyncState != null) {
+                for (DataObject f : newSyncState) {
+                    if (f.getChangeState() != ChangeState.UNMODIFIED)
+                        newSyncObjects += "postsync: newSyncState " + f.toString() + "\n"; 
+                }
+            }
+            if (changedObjects != null) {
+                for (DataObject f : changedObjects) {
+                    if (f.getChangeState() != ChangeState.UNMODIFIED)
+                        changes += "postsync: serverChange " + f.toString() + "\n"; 
+                }
+            }
+        
+            if (!newSyncObjects.isEmpty() || !changes.isEmpty())
+                _journal.trace(newSyncObjects + changes);
+        }
+	    
+	    return result;
+	}
+
+	    
+    private SyncResult syncChangesWithServerCore(ContentSyncerStorage storage, ConflictResolution conflictResolution,
+            DataObject[] lastSyncState, DataObject[] dataObjectChanges, long timestamp, int resultLimit,
+            DataObjectFilter filter, Comparator<? super DataObject> sorter) throws USMException {
 		if (lastSyncState == null)
 			throw new SlowSyncRequiredException(USMSessionManagementErrorCodes.NO_CACHED_DATA_INCR_SYNC,
 					"No cached DataObjects for client available");
