@@ -52,6 +52,7 @@ package com.openexchange.usm.util;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.util.Collection;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.List;
@@ -127,7 +128,7 @@ public class TempFileStorage {
         String id = getTempFileID(session, tempid);
         ManagedFileManagement fileManagement = _fileManagement;
         if (fileManagement != null) {
-            ManagedFile file = retrieveFileFromManagement(fileManagement, id);
+            ManagedFile file = retrieveFileFromManagement(fileManagement, id, offset > 0);
             return new TempFile(file, offset);
         }
         return getLocalFileStorage().getTempFileForWrite(id, offset);
@@ -158,7 +159,7 @@ public class TempFileStorage {
     }
 
     /**
-     * Deleted all temp files associated with a given USM session. Returns the number of temp files that have been deleted.
+     * Deletes all temp files associated with a given USM session. Returns the number of temp files that have been deleted.
      * 
      * @param session
      * @return number of temp files that have been deleted
@@ -168,13 +169,33 @@ public class TempFileStorage {
         ManagedFileManagement fileManagement = _fileManagement;
         if (fileManagement != null) {
             List<ManagedFile> filesToDelete = getManagedFilesToDelete(fileManagement, prefix);
-            for (ManagedFile file : filesToDelete)
+            for (ManagedFile file : filesToDelete) {
+                // TODO: Why not use fileManagement.removeByID(file.getID())?
                 file.delete();
+            }
             return filesToDelete.size();
         }
         return getLocalFileStorage().deleteTempFiles(prefix);
     }
 
+    /**
+     * Tries to delete all temp files associated with a given USM session and according to the given set of tempid's.
+     * 
+     * @param session
+     * @param tempIDs
+     * @return true if all files have been deleted, false if one file no longer exists or if one file could not be deleted
+     * @throws IOException If an OXException was thrown by the OX ManagedFileManagement
+     */
+    public static boolean deleteTempFiles(Session session, Collection<String> tempIDs) throws IOException {
+        boolean successful = true;
+        
+        for (String tempid : tempIDs) {
+            if (!deleteTempFile(session, tempid))
+                successful = false;
+        }
+        return successful;
+    }
+
     /**
      * Tries to delete the temp file with the given client tempid for the specified USM session.
      * 
@@ -207,11 +228,13 @@ public class TempFileStorage {
         }
     }
 
-    private static ManagedFile retrieveFileFromManagement(ManagedFileManagement fileManagement, String id) throws IOException {
+    private static ManagedFile retrieveFileFromManagement(ManagedFileManagement fileManagement, String id, Boolean toBeReused) throws IOException {
         try {
             if (fileManagement.containsLocal(id))
                 return fileManagement.getByID(id);
-            return fileManagement.createManagedFile(id, _EMPTY_INPUT_STREAM, _tempFileTimeout);
+            if (!toBeReused)
+                return fileManagement.createManagedFile(id, _EMPTY_INPUT_STREAM, _tempFileTimeout);
+            throw new IOException("Expected temp file for append did not exist! id=" + id);
         } catch (OXException e) {
             throw new IOException("Error accessing temp file " + id, e);
         }
